@@ -2,19 +2,21 @@ package Travel::Status::DE::HAFAS;
 
 use strict;
 use warnings;
-use 5.010;
+use 5.014;
 use utf8;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
 use Carp qw(confess);
+use DateTime;
+use DateTime::Format::Strptime;
 use LWP::UserAgent;
 use POSIX qw(strftime);
 use Travel::Status::DE::HAFAS::Result;
 use Travel::Status::DE::HAFAS::StopFinder;
 use XML::LibXML;
 
-our $VERSION = '2.01';
+our $VERSION = '2.03';
 
 my %hafas_instance = (
 	BVG => {
@@ -24,8 +26,8 @@ my %hafas_instance = (
 		productbits => [qw[s u tram bus ferry ice regio ondemand]],
 	},
 	DB => {
-		url        => 'http://reiseauskunft.bahn.de/bin/bhftafel.exe',
-		stopfinder => 'http://reiseauskunft.bahn.de/bin/ajax-getstop.exe',
+		url        => 'https://reiseauskunft.bahn.de/bin/bhftafel.exe',
+		stopfinder => 'https://reiseauskunft.bahn.de/bin/ajax-getstop.exe',
 		name       => 'Deutsche Bahn',
 		productbits =>
 		  [qw[ice ic_ec d regio s bus ferry u tram ondemand x x x x]],
@@ -291,6 +293,14 @@ sub results {
 
 	$self->{results} = [];
 
+	$self->{datetime_now} //= DateTime->now(
+		time_zone => 'Europe/Berlin',
+	);
+	$self->{strptime_obj} //= DateTime::Format::Strptime->new(
+		pattern   => '%d.%m.%YT%H:%M',
+		time_zone => 'Europe/Berlin',
+	);
+
 	for my $tr ( @{ $self->{tree}->findnodes($xp_element) } ) {
 
 		my @message_nodes = $tr->findnodes($xp_msg);
@@ -328,10 +338,14 @@ sub results {
 
 		$train =~ s{#.*$}{};
 
+		my $datetime = $self->{strptime_obj}->parse_datetime("${date}T${time}");
+
 		push(
 			@{ $self->{results} },
 			Travel::Status::DE::HAFAS::Result->new(
 				date         => $date,
+				datetime     => $datetime,
+				datetime_now => $self->{datetime_now},
 				raw_delay    => $delay,
 				raw_e_delay  => $e_delay,
 				messages     => \@messages,
@@ -411,7 +425,7 @@ monitors
 
 =head1 VERSION
 
-version 2.01
+version 2.03
 
 =head1 DESCRIPTION
 
@@ -555,6 +569,10 @@ None.
 
 =item * Class::Accessor(3pm)
 
+=item * DateTime(3pm)
+
+=item * DateTime::Format::Strptime(3pm)
+
 =item * LWP::UserAgent(3pm)
 
 =item * XML::LibXML(3pm)
@@ -571,7 +589,7 @@ Travel::Status::DE::HAFAS::Result(3pm), Travel::Status::DE::HAFAS::StopFinder(3p
 
 =head1 AUTHOR
 
-Copyright (C) 2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2015-2017 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
