@@ -2,16 +2,16 @@ package Travel::Status::DE::HAFAS::Result;
 
 use strict;
 use warnings;
-use 5.010;
+use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
 use parent 'Class::Accessor';
 
-our $VERSION = '2.01';
+our $VERSION = '2.03';
 
 Travel::Status::DE::HAFAS::Result->mk_ro_accessors(
-	qw(date info raw_e_delay raw_delay time train route_end));
+	qw(date datetime info raw_e_delay raw_delay time train route_end));
 
 sub new {
 	my ( $obj, %conf ) = @_;
@@ -21,6 +21,26 @@ sub new {
 	return bless( $ref, $obj );
 }
 
+sub countdown {
+	my ($self) = @_;
+
+	$self->{countdown}
+	  //= $self->datetime->subtract_datetime( $self->{datetime_now} )
+	  ->in_units('minutes');
+
+	return $self->{countdown};
+}
+
+sub countdown_sec {
+	my ($self) = @_;
+
+	$self->{countdown_sec}
+	  //= $self->datetime->subtract_datetime( $self->{datetime_now} )
+	  ->in_units('seconds');
+
+	return $self->{countdown_sec};
+}
+
 sub delay {
 	my ($self) = @_;
 
@@ -170,7 +190,7 @@ arrival/departure received by Travel::Status::DE::HAFAS
 
 =head1 VERSION
 
-version 2.01
+version 2.03
 
 =head1 DESCRIPTION
 
@@ -184,10 +204,24 @@ the platform, time, route and more.
 
 =over
 
+=item $result->countdown
+
+Difference between the time Travel::Status::DE::HAFAS->results
+was called first and the arrival/departure time, in minutes.
+
+=item $result->countdown_sec
+
+Difference between the time Travel::Status::DE::HAFAS->results
+was called first and the arrival/departure time, in seconds.
+
 =item $result->date
 
 Arrival/Departure date in "dd.mm.yyyy" format.
 
+=item $result->datetime
+
+DateTime object holding the arrival/departure date and time.
+
 =item $result->delay
 
 Returns the delay in minutes, or undef if it is unknown.
@@ -278,7 +312,7 @@ Travel::Status::DE::HAFAS(3pm).
 
 =head1 AUTHOR
 
-Copyright (C) 2015 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2015-2017 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
